==> deepin-screen-recorder_5.9.6.orig.tar.xz: deepin-screen-recorder-5.9.6/translations/deepin-screen-recorder_en_US.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Click the tray icon 
or press the shortcut again to stop recording</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Record</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Screen Capture</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Save failed. Please save it in your home directory.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>View</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Screenshot finished</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>select-area</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Save</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Saved to %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignore</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Clipboard</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Saving the screen recording file, please wait...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>As the window effect is disabled during the process, the recording has to be stopped</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Undo</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Save</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>View</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Recording finished</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Saved to %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Record</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Screen Capture will start in %1 seconds</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Input text here</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Start/Screenshot</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Exit/Save</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Drawing</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Size Adjustment</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Quick start</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Window screenshot</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Delay screenshot</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Full screenshot</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Save</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Line</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Pencil</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Undo</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Increase height up</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Increase height down</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Increase width left</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Increase width right</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Decrease height up</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Decrease height down</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Decrease width left</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Decrease width right</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Display shortcuts</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sound</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Keystroke</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Start recording</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Start/Recording</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Mouse</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Blur</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mosaic</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Sound On</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Microphone</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>System Audio</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Sound Off</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Show Keystroke</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Hide Keystroke</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webcam On</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webcam Off</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Show Click</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Line</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Arrow</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Pencil</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Save to</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Pictures</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Folder</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Clipboard</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Show pointer</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Mouse</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Show Pointer</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Adjust the recording area within %1*%2 to get better video effect</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Recordings</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.10.15.orig.tar.xz: deepin-screen-recorder-5.10.15/translations/deepin-screen-recorder_en_US.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Click the tray icon 
or press the shortcut again to stop recording</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Do not rotate your screen during recording</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Record</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Screen Capture</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Save failed. Please save it in your home directory.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>View</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Screenshot finished</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>select-area</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Save</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Saved to %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignore</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Clipboard</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Saving the screen recording file, please wait...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>As the window effect is disabled during the process, the recording has to be stopped</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
    <message>
        <source>The screenshot has been saved in the album</source>
        <translation>The screenshot has been saved in the album</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>Screenshot failed.</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Undo</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Save</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>View</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Recording finished</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Saved to %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Record</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Screen Capture will start in %1 seconds</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Get help.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Failed to take a continuous screenshot.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Reached the bottom of the scroll area</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Reached the maximum length</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>adjust the capture area</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Scroll your mouse wheel or click to take a scrolling screenshot</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Slow down the scrolling speed</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Invalid area, click to </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Input text here</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Start/Screenshot</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Exit/Save</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Size Adjustment</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Quick start</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Window screenshot</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Delay screenshot</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Full screenshot</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Save</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Line</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Pencil</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Undo</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Increase height up</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Increase height down</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Increase width left</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Increase width right</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Decrease height up</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Decrease height down</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Decrease width left</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Decrease width right</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Display shortcuts</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sound</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Keystroke</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Start recording</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Start/Recording</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Mouse</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Tools</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extract text</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Pin screenshots</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Blur</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mosaic</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Sound On</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Microphone</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>System Audio</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Sound Off</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Show Keystroke</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Hide Keystroke</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webcam On</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webcam Off</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Show Click</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Line</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Arrow</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Pencil</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Save to</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Pictures</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Folder</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Clipboard</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Show pointer</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Mouse</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Show Pointer</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Extract Text</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Pin screenshots</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Adjust the recording area within %1*%2 to get better video effect</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Screen recording is not supported at present</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
</context>
</TS>
